/*
 * mbed library program
 *  LPS25H MEMS pressure sensor: 260-1260 hPa absolute digital output barometer
 *   made by STMicroelectronics
 *   http://www.st-japan.co.jp/web/catalog/sense_power/FM89/SC1316/PF255230
 * Copyright (c) 2015,'17 Kenji Arai / JH1PJL
 *      Created: Feburary  21st, 2015
 *      Revised: August    21st, 2017
 */

#ifndef LPS25H_H
#define LPS25H_H

#include "mbed.h"

//  LPS25H Address
//  7bit address = 0b101110x(0x5c or 0x5d depends on SA0/SDO)
#define LPS25H_G_CHIP_ADDR  (0x5c << 1)    // SA0(=SDO pin) = Ground
#define LPS25H_V_CHIP_ADDR  (0x5d << 1)    // SA0(=SDO pin) = Vdd

// MODE Selection
#define FIFO_HW_FILTER          1
#define FIFO_BYPASS             0

//  Register's definition
#define LPS25H_RES_CONF        0x10
#define LPS25H_CTRL_REG1       0x20
#define LPS25H_CTRL_REG2       0x21
#define LPS25H_PRESS_POUT_XL   0x28
#define LPS25H_FIFO_CTRL       0x2e

// Control Reg.
#define CR_STD_SET      ( (1UL << 7) + (1UL << 4) + (1UL << 2) )

class LPS25H
{
public:
    LPS25H(PinName p_sda, PinName p_scl);
    void get(void);                 // Start convertion & data save
    float pressure(void);           // Read pressure data
    float altitude(void);                       // Read altitude data; return altitude in

protected:
    I2C *_i2c_p;
    I2C &_i2c;
    void init(void);

private:
    char dt[6];            // working buffer
    uint8_t LPS25H_addr;   // Sensor address
    //uint8_t LPS25H_id;     // ID
    uint8_t LPS25H_ready;  // Device is on I2C line = 1, not = 0
    uint8_t LPS25H_mode;   // Operation mode
    uint32_t press;        // pressure raw data
    int32_t alt;
};

#endif      // LPS25H_H
